#
# spec file for package python-coverage
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-coverage
Version:        4.3.4
Release:        1.1
Url:            http://nedbatchelder.com/code/coverage/%{version}
Summary:        Code coverage measurement for Python
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/c/coverage/coverage-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# Test requirements:
#BuildRequires:  python-mock
#BuildRequires:  python-nose
Requires:       python-setuptools
Requires:       python-xml
Requires(pre):  coreutils
Requires(post): /usr/sbin/update-alternatives
Requires(postun): /usr/sbin/update-alternatives

%python_subpackages

%description
Coverage.py measures code coverage, typically during test execution. It uses
the code analysis tools and tracing hooks provided in the Python standard
library to determine which lines are executable, and which have been executed.

%prep
%setup -q -n coverage-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/coverage
ln -sf coverage-%{python2_version} %{buildroot}%{_bindir}/coverage2
ln -sf coverage-%{python3_version} %{buildroot}%{_bindir}/coverage3

#NOTE(saschpe): The following seems to mess with the install dir, which is odd:
#%%check
# Taken straight from tox.ini:
#python setup.py develop
#python igor.py zip_mods install_egg remove_extension 
#python igor.py test_with_tracer py
#python setup.py --quiet build_ext --inplace
#python igor.py test_with_tracer c

%post
%python_install_alternative coverage

%postun
%python_uninstall_alternative coverage

%files %python_files
%defattr(-,root,root,-)
%doc CHANGES.rst CONTRIBUTORS.txt README.rst LICENSE.txt TODO.txt howto.txt
%python_alternative %{_bindir}/coverage
%python2_only %{_bindir}/coverage2
%python3_only %{_bindir}/coverage3
%{python_sitearch}/coverage/
%{python_sitearch}/coverage-%{version}-py%{python_version}.egg-info

%changelog
* Wed Mar 29 2017 jmatejek@suse.com
- uninstall alternatives in %%postun
* Mon Mar 13 2017 jmatejek@suse.com
- update for singlespec
- update to 4.3.4:
  - Using the --skip-covered option on an HTML report with 100%% coverage would
    cause a “No data to report” error, as reported in issue 549. This is now
    fixed; thanks, Loïc Dachary.
  - If-statements can be optimized away during compilation, for example, if 0:
    or if __debug__:. Coverage.py had problems properly understanding these
    statements which existed in the source, but not in the compiled bytecode.
    This problem, reported in issue 522, is now fixed.
  - If you specified --source as a directory, then coverage.py would look for
    importable Python files in that directory, and could identify ones that had
    never been executed at all. But if you specified it as a package name, that
    detection wasn’t performed. Now it is, closing issue 426. Thanks to Loïc
    Dachary for the fix.
  - If you started and stopped coverage measurement thousands of times in your
    process, you could crash Python with a “Fatal Python error: deallocating
    None” error. This is now fixed. Thanks to Alex Groce for the bug report.
  - On PyPy, measuring coverage in subprocesses could produce a warning: “Trace
    function changed, measurement is likely wrong: None”. This was spurious,
    and has been suppressed.
  - Previously, coverage.py couldn’t start on Jython, due to that
    implementation missing the multiprocessing module (issue 551). This problem
    has now been fixed. Also, issue 322 about not being able to invoke coverage
    conveniently, seems much better: jython -m coverage run myprog.py works
    properly.
  - Let’s say you ran the HTML report over and over again in the same output
    directory, with --skip-covered. And imagine due to your heroic test-writing
    efforts, a file just acheived the goal of 100%% coverage. With coverage.py
    4.3, the old HTML file with the less-than-100%% coverage would be left
    behind. This file is now properly deleted.
* Sat Jan 14 2017 hpj@urpla.net
- update to Version 4.3.1 — 2016-12-28:
  - Some environments couldn’t install 4.3, as described in issue 540. This is
    now fixed.
  - The check for conflicting --source and --include was too simple in a few
    different ways, breaking a few perfectly reasonable use cases, described in
    issue 541. The check has been reverted while we re-think the fix for issue 265.
- update to Version 4.3 — 2016-12-27:
  Special thanks to Loïc Dachary, who took an extraordinary interest in
  coverage.py and contributed a number of improvements in this release.
  - The HTML report now supports a --skip-covered option like the other
    reporting commands. Thanks, Loïc Dachary for the implementation, closing
    issue 433.
  - Subprocesses that are measured with automatic subprocess measurement used
    to read in any pre-existing data file. This meant data would be incorrectly
    carried forward from run to run. Now those files are not read, so each
    subprocess only writes its own data. Fixes issue 510.
  - Coverage.py wouldn’t execute sys.excepthook when an exception happened in
    your program. Now it does, thanks to Andrew Hoos. Closes issue 535.
  - The coverage combine command will now fail if there are no data files to
    combine. The combine changes in 4.2 meant that multiple combines could lose
    data, leaving you with an empty .coverage data file. Fixes issues issue 525,
    issue 412, issue 516, and probably issue 511.
  - The branch coverage issues described in issue 493, issue 496, and issue 502
    are now fixed, thanks to Loïc Dachary.
  - Options can now be read from a tox.ini file, if any. Like setup.cfg,
    sections are prefixed with “coverage:”, so [run] options will be read from
    the [coverage:run] section of tox.ini. Implements part of issue 519. Thanks,
    Stephen Finucane.
  - Specifying both --source and --include no longer silently ignores the
    include setting, instead it fails with a message. Thanks, Nathan Land and
    Loïc Dachary. Closes issue 265.
  - Coverage.py can now search .pex files for source, just as it can .zip and
    .egg. Thanks, Peter Ebden.
* Tue Nov 15 2016 dmueller@suse.com
- update to 4.2:
  - Since ``concurrency=multiprocessing`` uses subprocesses, options specified on
    the coverage.py command line will not be communicated down to them.  Only
    options in the configuration file will apply to the subprocesses.
    Previously, the options didn't apply to the subprocesses, but there was no
    indication.  Now it is an error to use ``--concurrency=multiprocessing`` and
    other run-affecting options on the command line.  This prevents
    failures like those reported in `issue 495`_.
  - Filtering the HTML report is now faster, thanks to Ville Skyttä.
* Mon Dec 28 2015 marec@detebe.org
- update to 4.0.3:
  - Fixed a mysterious problem that manifested in different ways: sometimes
    hanging the process (`issue 420`_), sometimes making database connections
    fail (`issue 445`_).
  - The XML report now has correct ``<source>`` elements when using a
    ``--source=`` option somewhere besides the current directory.  This fixes
    `issue 439`_. Thanks, Arcady Ivanov.
  - Fixed an unusual edge case of detecting source encodings, described in
    `issue 443`_.
  - Help messages that mention the command to use now properly use the actual
    command name, which might be different than "coverage".  Thanks to Ben Finney,
    this closes `issue 438`_.
* Sat Oct 31 2015 dmueller@suse.com
- add LICENSE.txt
* Fri Oct 16 2015 bgeuken@suse.com
- Pre require coreutils. This package is needed for the rm call in the pre section.
    Subprocess failed. Error: RPM failed: /var/tmp/rpm-tmp.gONanE: line 3: rm: command not found
* Wed Oct  7 2015 arun@gmx.de
- specfile:
  * updated license
  * updated update-alternatives
  * README.txt -> README.rst
- update to version 4.0:
  (long list, see http://coverage.readthedocs.org/en/latest/changes.html)
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix rhel deps by depending on /usr/sbin/update-alternatives
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu May  8 2014 toddrme2178@gmail.com
- update to 3.7.1:
  - Improved the speed of HTML report generation by about 20%%.
  - Fixed the mechanism for finding OS-installed static files for the HTML report
    so that it will actually find OS-installed static files.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Oct 21 2013 dmueller@suse.com
- update to 3.7:
  * Added the ``--debug`` switch to ``coverage run``.  It accepts a list of
  options indicating the type of internal activity to log to stderr.
  * Running code with ``coverage run -m`` now behaves more like Python does,
  setting sys.path properly, which fixes `issue 207`_ and `issue 242`_.
  * Coverage can now run .pyc files directly, closing `issue 264`_.
  Over 15 other bugfixes, see included CHANGELOG
* Wed May 15 2013 speilicke@suse.com
- Fix update-alternatives and support upgrade from previous versions
* Fri May  3 2013 speilicke@suse.com
- Apply update-alternatives for binaries and man-pages
- Drop buildrequires on python-xml, I don't see it being used
* Mon Apr 29 2013 dmueller@suse.com
- update to 3.6:
  * Fix Nose support
  * Add --fail-under
  * Over 20 bug fixes, for details see included CHANGELOG
* Tue Nov 20 2012 saschpe@suse.de
- Update to version 3.5.3:
  + Line numbers in the HTML report line up better with the source lines, fixing
    issue 197
  + When specifying a directory as the source= option, the directory itself no
    longer needs to have a __init__.py file, though its subdirectories do, to
    be considered as source files.
  + Files encoded as UTF-8 with a BOM are now properly handled, fixing
    issue 179_.
  + Fixed more cases of non-Python files being reported as Python source, and
    then not being able to parse them as Python.  Closes issue 82 (again).
  + Fixed memory leaks under Python 3, thanks, Brett Cannon. Closes issue 147_.
  + Optimized .pyo files may not have been handled correctly, issue 195_.
  + Certain unusually named file paths could have been mangled during reporting,
    issue 194_.
  + Try to do a better job of the impossible task of detecting when we can't
    build the C extension, fixing issue 183_.
  + Testing is now done with tox
- Changes from version 3.5.2:
  + No changes since 3.5.2.b1
- Changes from version 3.5.2b1
  + The HTML report has slightly tweaked controls: the buttons at the top of
    the page are color-coded to the source lines they affect.
  + Custom CSS can be applied to the HTML report by specifying a CSS file as
    the extra_css configuration value in the [html] section.
  + Source files with custom encodings declared in a comment at the top are now
    properly handled during reporting on Python 2.  Python 3 always handled them
    properly.  This fixes issue 157_.
  + Backup files left behind by editors are no longer collected by the source=
    option, fixing issue 168_.
  + If a file doesn't parse properly as Python, we don't report it as an error
    if the filename seems like maybe it wasn't meant to be Python.  This is a
    pragmatic fix for issue 82_.
  + The -m switch on coverage report, which includes missing line numbers
    in the summary report, can now be specifed as show_missing in the
    config file.  Closes issue 173_.
  + When running a module with coverage run -m <modulename>, certain details
    of the execution environment weren't the same as for
    python -m <modulename>.  This had the unfortunate side-effect of making
    coverage run -m unittest discover not work if you had tests in a
    directory named "test".  This fixes issue 155_.
  + Now the exit status of your product code is properly used as the process
    status when running python -m coverage run ....  Thanks, JT Olds.
  + When installing into pypy, we no longer attempt (and fail) to compile
    the C tracer function, closing issue 166_.
* Thu May 24 2012 cfarrell@suse.com
- license update: BSD-2-Clause and (GPL-2.0+ or MIT)
  __init__.py is the only file with a definitive license statement
  (BSD-2-Clause). Also, package contains jquery components (GPL-2.0+ or
  MIT)
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
- minor spec improvement (files section)
* Sat Mar 10 2012 saschpe@gmx.de
- Simplify macro usage
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 3.5.1:
  * The [paths] feature unfortunately didn't work in real world situations
    where you wanted to, you know, report on the combined data.  Now all paths
    stored in the combined file are canonicalized properly.
* Tue Sep 27 2011 saschpe@suse.de
- Add python-distribute runtime requirement
* Thu Sep  8 2011 saschpe@suse.de
- Update to version 3.5.1b1:
  * for-else constructs are understood better, and don't cause erroneous partial
    branch warnings.  Fixes issue 122.
  * Branch coverage for with statements is improved, fixing issue 128.
  * The number of partial branches reported on the HTML summary page was
    different than the number reported on the individual file pages.  This is
    now fixed.
  * An explicit include directive to measure files in the Python installation
    wouldn't work because of the standard library exclusion.  Now the include
    directive takes precendence, and the files will be measured.  Fixes
    issue 138.
  * The HTML report now handles Unicode characters in Python source files
    properly. This fixes issue 124 and issue 144. Thanks, Devin
    Jeanpierre.
  * In order to help the core developers measure the test coverage of the
    standard library, Brandon Rhodes devised an aggressive hack to trick Python
    into running some coverage code before anything else in the process.
    See the coverage/fullcoverage directory if you are interested.
  ...see CHANGES.txt for more
- Spec file cleanup:
  * Use python-distribute instead of python-setuptools
  * Changed license to BSD-3-Clause (SPDX style)
* Fri May  6 2011 saschpe@suse.de
- Update to version 3.4:
  + The XML report is now sorted by package name, fixing issue 88.
  + Programs that exited with sys.exit() with no argument weren't handled
    properly, producing a coverage.py stack trace.  That is now fixed.
- Changes from version 3.3.1:
  + Using parallel=True in .coveragerc file prevented reporting, but now does
    not, fixing issue 49.
  + When running your code with "coverage run", if you call sys.exit(),
    coverage.py will exit with that status code, fixing issue 50.
- Added documentation (AUTHORS.txt, CHANGES.txt and README.txt)
- Addded changes file
* Sat Aug 22 2009 cfarrell1980@gmail.com
- Require setuptools
* Thu May 28 2009 cfarrell1980@gmail.com
- Initial import
